<?php
/**
 * The Header for our theme.
 *
 * Displays all of the <head> section and everything up till <div id="main">
 *
 * @package WordPress
 * @subpackage Twenty_Eleven
 * @since Twenty Eleven 1.0
 */
?><!DOCTYPE html>
<!--[if IE 6]>
<html id="ie6" <?php language_attributes(); ?>>
<link rel="stylesheet" href="<?php bloginfo( 'stylesheet_directory' ); ?>/ie6.css" />
<![endif]-->
<!--[if IE 7]>
<html id="ie7" <?php language_attributes(); ?>>
<![endif]-->
<!--[if IE 8]>
<html id="ie8" <?php language_attributes(); ?>>
<![endif]-->
<!--[if !(IE 6) | !(IE 7) | !(IE 8)  ]><!-->
<html <?php language_attributes(); ?>>
<!--<![endif]-->
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>" />
<meta name="viewport" content="width=device-width" />
<?php
	global $is_lynx, $is_gecko, $is_IE, $is_opera, $is_NS4, $is_safari, $is_chrome, $is_iphone;
	if( $is_iphone ) : ?>
<meta name="format-detection" content="telephone=no" />
<?php endif; ?>
<title><?php
	/*
	 * Print the <title> tag based on what is being viewed.
	 */
	global $page, $paged;

	wp_title( '|', true, 'right' );

	// Add the blog name.
	bloginfo( 'name' );

	// Add the blog description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		echo " | $site_description";

	// Add a page number if necessary:
	if ( $paged >= 2 || $page >= 2 )
		echo ' | ' . sprintf( __( 'Page %s', 'twentyeleven' ), max( $paged, $page ) );

	?></title>



<link rel="profile" href="http://gmpg.org/xfn/11" />
<link rel="stylesheet" type="text/css" media="all" href="<?php bloginfo( 'stylesheet_url' ); ?>" />
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>" />
<!--[if lt IE 9]>
<script src="<?php echo get_template_directory_uri(); ?>/js/html5.js" type="text/javascript"></script>
<![endif]-->
<?php
	/* We add some JavaScript to pages with the comment form
	 * to support sites with threaded comments (when in use).
	 */
	if ( is_singular() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

	/* Always have wp_head() just before the closing </head>
	 * tag of your theme, or you will break many plugins, which
	 * generally use this hook to add elements to <head> such
	 * as styles, scripts, and meta tags.
	 */
	wp_head();
?>
<script src="<?php bloginfo( 'stylesheet_directory' ); ?>/js/add_remove.js"></script>
<script src="<?php bloginfo( 'stylesheet_directory' ); ?>/js/smooth_accordion.js"></script>
<?php if( is_page( 'banner' ) ) : ?>
<script src="<?php bloginfo( 'stylesheet_directory' ); ?>/js/focus.js"></script>
<?php elseif( is_page( 'program' ) ) : ?>
<link rel="stylesheet" href="<?php bloginfo( 'stylesheet_directory' ); ?>/responsive/responsive-tables.css"/>
<?php endif; ?>
</head>

<body id="here" <?php my_body_class(); ?>>
<div id="page" class="hfeed">
	<header id="branding" role="banner">
	<?php if( !is_user_logged_in() ) { ?>
	<a class="loginout_link" href="<?php echo wp_login_url() ?>">ログイン</a>
	<?php } else { ?>
	<a class="loginout_link" href="<?php echo wp_logout_url() ?>?redirect_to=<?php echo esc_attr($_SERVER['REQUEST_URI']) ?>">ログアウト</a>
	<?php } ?>
			<hgroup>
				<h1 id="site-title"><span><a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></span></h1>
				<h2 id="site-description"><?php bloginfo( 'description' ); ?></h2>
			</hgroup>

			<?php
				// Check to see if the header image has been removed
				$header_image = get_header_image();
				if ( ! empty( $header_image ) ) :
			?>
			<a href="<?php echo esc_url( home_url( '/' ) ); ?>">
				<?php
					// The header image
					// Check if this is a post or page, if it has a thumbnail, and if it's a big one
					if ( is_singular() &&
							has_post_thumbnail( $post->ID ) &&
							( /* $src, $width, $height */ $image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), array( HEADER_IMAGE_WIDTH, HEADER_IMAGE_WIDTH ) ) ) &&
							$image[1] >= HEADER_IMAGE_WIDTH ) :
						// Houston, we have a new header image!
						echo get_the_post_thumbnail( $post->ID, 'post-thumbnail' );
					else : ?>
					
					<?php if( is_home() ) : ?>
					<img src="<?php bloginfo( 'stylesheet_directory' ); ?>/images/common/global_header.gif" width="1000" height="537" alt="WordVolcano 2012 SUMMER" />
					<a id="to_join" href="<?php bloginfo( 'url' ); ?>/join"><img src="<?php bloginfo( 'stylesheet_directory' ); ?>/images/common/button_join.png" title="Let's Join!!" alt="" /></a>
					<?php else : ?>
					<img src="<?php bloginfo( 'stylesheet_directory' ); ?>/images/common/header.gif" width="1000" height="238" alt="WordVolcano 2012 SUMMER" />
					<a id="to_join" href="<?php bloginfo( 'url' ); ?>/join"><img src="<?php bloginfo( 'stylesheet_directory' ); ?>/images/common/button_join_other.png" title="Let's Join!!" alt="" /></a>
					<?php endif; ?>
					
				<?php endif; // end check for featured image or standard header ?>
			</a>
			<?php endif; // end check for removed header image ?>

			<!-- 検索フォーム -->
			<!--<?php
				// Has the text been hidden?
				if ( 'blank' == get_header_textcolor() ) :
			?>
				<div class="only-search<?php if ( ! empty( $header_image ) ) : ?> with-image<?php endif; ?>">
				<?php get_search_form(); ?>
				</div>
			<?php
				else :
			?>
				<?php get_search_form(); ?>
			<?php endif; ?>
			-->
			<!-- 検索フォーム -->
			
			
			
			<nav id="access" class="clearfix" role="navigation">
				<h3 class="assistive-text">Main menu<span>click or tap ;p</span></h3>
				<?php /*  Allow screen readers / text browsers to skip the navigation menu and get right to the good stuff. */ ?>
				<div id="skip_main" class="skip-link"><a class="assistive-text" href="#content" title="<?php esc_attr_e( 'Skip to primary content', 'twentyeleven' ); ?>"><?php _e( 'Skip to primary content', 'twentyeleven' ); ?></a></div>
				<div id="skip_sub" class="skip-link"><a class="assistive-text" href="#secondary" title="<?php esc_attr_e( 'Skip to secondary content', 'twentyeleven' ); ?>"><?php _e( 'Skip to secondary content', 'twentyeleven' ); ?></a></div>
				<?php /* Our navigation menu.  If one isn't filled out, wp_nav_menu falls back to wp_page_menu. The menu assiged to the primary position is the one used. If none is assigned, the menu with the lowest ID is used. */ ?>
				
				
					<?php wp_page_menu( 'sort_column=menu_order&show_home=0&exclude=25, 1498, 2048, 2056, 2075'); ?>
					
				<!-- #access_inner end --><!--</div>-->
			</nav><!-- #access -->
	</header><!-- #branding -->


	<div id="main">